@@ -2,7 +2,7 @@ var port_8c =
 [
     [ "pw_port_add", "port_8c.html#a716885ca156041daf98120c62d24123b", null ],
     [ "pw_port_add_listener", "port_8c.html#a6d61253f97045f6452627a0de7e0a0fc", null ],
-    [ "pw_port_alloc_buffers", "port_8c.html#a43d86abb25c2cf3f71b96baae0c9d2a9", null ],
+    [ "pw_port_alloc_buffers", "port_8c.html#a80e4664aa37f5670d5e3b7859dadc9c6", null ],
     [ "pw_port_destroy", "port_8c.html#a8852e0592fc0575a6cf755f00b67f7ef", null ],
     [ "pw_port_get_direction", "port_8c.html#a53aab0d888eb07c1543dee1c55e5c681", null ],
     [ "pw_port_get_id", "port_8c.html#a2461fe53d57c257892e36e7d37ae3e24", null ],
@@ -10,7 +10,9 @@ var port_8c =
     [ "pw_port_get_properties", "port_8c.html#a265fceb6afcbf35100789c8604adb8ef", null ],
     [ "pw_port_get_user_data", "port_8c.html#aa54010051af237b74def97bbee028975", null ],
     [ "pw_port_new", "port_8c.html#a59a008cb42bb3f7d8bf8aacfbda2a2f2", null ],
-    [ "pw_port_set_format", "port_8c.html#a6d3469eb98b0802e1991f945c4bc2325", null ],
+    [ "pw_port_pause", "port_8c.html#a0d5379e9d9f1f4ea37733042166c7c82", null ],
+    [ "pw_port_send_command", "port_8c.html#aa5f0d2bacd54660e2d2bf0149f4f256d", null ],
+    [ "pw_port_set_param", "port_8c.html#ae4bedd2b2c16b7699ab39f00a00fee38", null ],
     [ "pw_port_update_properties", "port_8c.html#aa6db18569f26be70bb759b416be52c12", null ],
     [ "pw_port_use_buffers", "port_8c.html#aa832bfdbd4b9f74a9d6432f84b587db1", null ]
 ];
\ No newline at end of file
